/// The meta-annotation that is used to generate Equatable props.
class Props {
  /// Creates the [Props] instance that is used for Equatable props generation.
  const Props();
}

/// The meta-annotation is used to exclude a field
/// from Equatable props generation.
class PropsExclude {
  /// Creates the [PropsExclude] instance that is used to exclude a field
  /// from Equatable props generation.
  const PropsExclude();
}

/// The meta-annotation that is used to generate Equatable props.
const props = Props();

/// The meta-annotation is used to exclude a field
/// from Equatable props generation.
const propsExclude = PropsExclude();

/// The meta-annotation is used to generate copyWith
/// and copyWithNull methods.
class CopyWith {
  /// The flag that indicates copyWithNull generation is needed.
  final bool copyWithNull;

  /// Creates the [CopyWith] instance that is used to generate copyWith
  /// and copyWithNull methods.
  /// The copyWithNull method will be generated if the [copyWithNull] is true.
  const CopyWith({this.copyWithNull = true});
}

/// The meta-annotation is used to exclude a field from copyWith
/// and copyWithNull methods generation.
class CopyWithExclude {
  /// Creates [CopyWithExclude] instance that is used to exclude a field from copyWith
  /// and copyWithNull methods generation.
  const CopyWithExclude();
}

/// The meta-annotation is used to generate copyWith
/// and copyWithNull methods.
///
/// The copyWithNull method will be generated by default.
const copyWith = CopyWith();

/// The meta-annotation is used to exclude a field from copyWith
/// and copyWithNull methods generation.
const copyWithExclude = CopyWithExclude();
